Coverage for airflow.hooks.mssql_hook: 70%

# Coverage for airflow.hooks.mssql_hook : 70%

## 10 statements 7 run 3 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 | import pymssql from airflow.hooks.dbapi_hook import DbApiHook class MsSqlHook(DbApiHook): ''' Interact with Microsoft SQL Server. ''' conn_name_attr = 'mssql_conn_id' default_conn_name = 'mssql_default' supports_autocommit = True def get_conn(self): """ Returns a mssql connection object """ conn = self.get_connection(self.mssql_conn_id) conn = pymssql.connect( conn.host, conn.login, conn.password, conn.schema) return conn